@@ -9,7 +9,8 @@ from textwrap import dedent
 
 from six import add_metaclass
 
-from virtualenv.create.via_global_ref.builtin.ref import ExePathRefToDest, PathRefToDest
+from virtualenv.create.via_global_ref.builtin.ref import ExePathRefToDest, PathRefToDest, RefMust
+from virtualenv.info import IS_MAC_ARM64
 from virtualenv.util.path import Path
 from virtualenv.util.six import ensure_text
 
@@ -29,7 +30,8 @@ class CPythonmacOsFramework(CPython):
         for src in super(CPythonmacOsFramework, cls).sources(interpreter):
             yield src
         # add a symlink to the host python image
-        ref = PathRefToDest(cls.image_ref(interpreter), dest=lambda self, _: self.dest / ".Python", must_symlink=True)
+        exe = cls.image_ref(interpreter)
+        ref = PathRefToDest(exe, dest=lambda self, _: self.dest / ".Python", must=RefMust.SYMLINK)
         yield ref
 
     def create(self):
@@ -40,7 +42,7 @@ class CPythonmacOsFramework(CPython):
         current = self.current_mach_o_image_path()
         for src in self._sources:
             if isinstance(src, ExePathRefToDest):
-                if src.must_copy or not self.symlinks:
+                if src.must == RefMust.COPY or not self.symlinks:
                     exes = [self.bin_dir / src.base]
                     if not self.symlinks:
                         exes.extend(self.bin_dir / a for a in src.aliases)
@@ -49,12 +51,12 @@ class CPythonmacOsFramework(CPython):
 
     @classmethod
     def _executables(cls, interpreter):
-        for _, targets in super(CPythonmacOsFramework, cls)._executables(interpreter):
+        for _, targets, must, when in super(CPythonmacOsFramework, cls)._executables(interpreter):
             # Make sure we use the embedded interpreter inside the framework, even if sys.executable points to the
             # stub executable in ${sys.prefix}/bin.
             # See http://groups.google.com/group/python-virtualenv/browse_thread/thread/17cab2f85da75951
             fixed_host_exe = Path(interpreter.prefix) / "Resources" / "Python.app" / "Contents" / "MacOS" / "Python"
-            yield fixed_host_exe, targets
+            yield fixed_host_exe, targets, must, when
 
     @abstractmethod
     def current_mach_o_image_path(self):
@@ -101,6 +103,13 @@ class CPython2macOsFramework(CPythonmacOsFramework, CPython2PosixBase):
         )
         return result
 
+    @classmethod
+    def can_create(cls, interpreter):
+        if IS_MAC_ARM64:
+            return False
+        else:
+            return super(CPythonmacOsFramework, cls).can_create(interpreter)
+
 
 class CPython3macOsFramework(CPythonmacOsFramework, CPython3, CPythonPosix):
     @classmethod
