@@ -13,10 +13,17 @@ else:
     Popen = subprocess.Popen
 
 
+CREATE_NO_WINDOW = 0x80000000
+
+
 def run_cmd(cmd):
     try:
         process = Popen(
-            cmd, universal_newlines=True, stdin=subprocess.PIPE, stderr=subprocess.PIPE, stdout=subprocess.PIPE,
+            cmd,
+            universal_newlines=True,
+            stdin=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            stdout=subprocess.PIPE,
         )
         out, err = process.communicate()  # input disabled
         code = process.returncode
@@ -29,4 +36,5 @@ __all__ = (
     "subprocess",
     "Popen",
     "run_cmd",
+    "CREATE_NO_WINDOW",
 )
